import logging
import os

import redis.sentinel

logger = logging.getLogger(__name__)

broker_hostname = os.getenv('BROKER_HOSTNAME')
assert broker_hostname is not None
broker_port = int(os.getenv('BROKER_PORT'))
broker_db_index = int(os.getenv('CELERY_DB_INDEX'))

broker_scheme = os.getenv('BROKER_SCHEME', 'redis')
assert broker_scheme in ('redis', 'sentinel'), 'unsupported broker scheme'

if broker_scheme == 'sentinel':
    master_name = os.getenv('SENTINEL_MASTER_NAME')
    assert master_name is not None
    sentinel = redis.sentinel.Sentinel(
        [(broker_hostname, broker_port)],
        socket_timeout=0.1)
    master = sentinel.discover_master(master_name)
    assert master
    broker_hostname = master[0]
    broker_port = master[1]

if ':' in broker_hostname:
    # assume this means hostname is an ipv6 address
    broker_hostname = '[%s]' % broker_hostname

broker_url = 'redis://%s:%d/%d' % (
    broker_hostname, broker_port, broker_db_index)
result_backend = broker_url

logger.debug('broker_url: %r' % broker_url)

task_eager_propagates = True
